==> cloudt-system-api-3.2.5.88-20231109.110630-1-sources.jar: com/elitescloud/cloudt/system/dto/req/EmployeePageQueryDTO.java <==
package com.elitescloud.cloudt.system.dto.req;

import com.elitescloud.boot.common.param.AbstractOrderQueryParam;
import lombok.Data;

import java.util.Set;

/**
 * 员工分页查询参数.
 *
 * @author Kaiser（wang shao）
 * @date 2/27/2023
 */
@Data
public class EmployeePageQueryDTO extends AbstractOrderQueryParam {
    private static final long serialVersionUID = 1211735072794036689L;

    /**
     * 员工ID
     */
    private Set<Long> ids;

    /**
     * 员工编号
     */
    private Set<String> codes;

    /**
     * 所属组织ID
     */
    private Long orgId;

    /**
     * 所属组织编码
     */
    private String orgCode;

    /**
     * 员工类型
     * <p>
     * {@link com.elitescloud.cloudt.system.constant.EmployeeType}
     * </p>
     */
    private String type;

    /**
     * 员工类型
     */
    private Set<String> types;

    /**
     * 启用状态
     */
    private Boolean enabled;

    /**
     * 登录账号
     */
    private String username;

    /**
     * 账号
     */
    private Set<String> usernames;

    /**
     * 用户ID
     */
    private Set<Long> userIds;

    /**
     * 手机号
     */
    private String phone;

    /**
     * 邮箱
     */
    private String email;

    /**
     * 姓名-姓氏
     */
    private String lastName;

    /**
     * 姓名-名字
     */
    private String firstName;

    /**
     * 是否在职
     */
    private Boolean served;

    /**
     * 是否查询下属员工数量，默认是
     */
    private Boolean withUnderlingNum = true;

    /**
     * 是否没有上级
     * true：查询没有领导的员工；false：查询有领导的员工；null：都查询，不过滤
     */
    private Boolean withoutLeader;

    /**
     * 是否不查询组织
     */
    private Boolean withoutOrg;

    /**
     * 上级组织类型
     * <p>
     * {@link com.elitescloud.cloudt.system.constant.OrgType}
     */
    private String withParentOrgType;
}

==> cloudt-system-api-3.4.1.35-20251121.084921-1-sources.jar: com/elitescloud/cloudt/system/dto/req/EmployeePageQueryDTO.java <==
package com.elitescloud.cloudt.system.dto.req;

import com.elitescloud.boot.common.param.AbstractOrderQueryParam;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.util.Set;

/**
 * 员工分页查询参数.
 *
 * @author Kaiser（wang shao）
 * @date 2/27/2023
 */
@Data
public class EmployeePageQueryDTO extends AbstractOrderQueryParam {
    private static final long serialVersionUID = 1211735072794036689L;

    /**
     * 员工ID
     */
    private Set<Long> ids;

    /**
     * 员工编号
     */
    private Set<String> codes;

    /**
     * 员工编号
     */
    private String code;

    /**
     * 直属组织ID
     */
    private Long orgId;

    /**
     * 直属组织编码
     */
    private String orgCode;

    @ApiModelProperty(value = "组织ID[下属]")
    private Long orgIdBelong;

    @ApiModelProperty(value = "组织编码[下属]")
    private String orgCodeBelong;

    /**
     * 员工类型
     * <p>
     * {@link com.elitescloud.cloudt.system.constant.EmployeeType}
     * </p>
     */
    private String type;

    /**
     * 员工类型
     */
    private Set<String> types;

    /**
     * 启用状态
     */
    private Boolean enabled;

    /**
     * 登录账号
     */
    private String username;

    /**
     * 账号
     */
    private Set<String> usernames;

    /**
     * 用户ID
     */
    private Set<Long> userIds;

    /**
     * 办公电话
     */
    private String phone;

    /**
     * 工作邮箱
     */
    private String emailWork;

    /**
     * 手机号
     */
    private String mobile;

    /**
     * 邮箱
     */
    private String email;

    /**
     * 姓名-姓氏
     */
    private String lastName;

    /**
     * 姓名-名字
     */
    private String firstName;

    /**
     * 是否在职
     */
    private Boolean served;

    /**
     * 姓名或手机号
     */
    private String usernameOrMobile;

    /**
     * 是否查询下属员工数量，默认是
     */
    private Boolean withUnderlingNum = true;

    /**
     * 是否查询上级领导
     */
    private Boolean withLeader = true;

    /**
     * 是否没有上级
     * true：查询没有领导的员工；false：查询有领导的员工；null：都查询，不过滤
     */
    private Boolean withoutLeader;

    /**
     * 是否不查询组织
     */
    private Boolean withoutOrg;

    /**
     * 是否不查询手机号
     */
    private Boolean withoutMobile;

    /**
     * 上级组织类型
     * <p>
     * {@link com.elitescloud.cloudt.system.constant.OrgType}
     */
    private String withParentOrgType;
}
